@@ -1,6 +1,7 @@
 from __future__ import absolute_import
 
 import logging
+import smtplib
 
 from django.conf import settings
 from django.core.mail import EmailMultiAlternatives
@@ -14,7 +15,7 @@ from .forms import forms_for_emailform, BaseOptionAnswer
 from .models import EmailForm, Entry, OPTION_TYPE_CHOICES
 
 from .util import ChoiceEnum
-from . import settings as local_settings
+from . import settings as emailform_settings
 
 
 def _get_remote_ip(request):
@@ -66,7 +67,7 @@ def _url_for_edit(request, obj):
         edit_url = reverse("admin:%s_%s_change" % view_args, args=(obj.id,))
     except NoReverseMatch:
         edit_url = "/admin/%s/%s/%d/" % (view_args + (obj.id,))
-    admin_url = local_settings.EMAILFORM_ADMIN_SITE
+    admin_url = emailform_settings.EMAILFORM_ADMIN_SITE
     if not admin_url:
         admin_url = "http://" + request.META["HTTP_HOST"]
     elif len(admin_url) < 4 or admin_url[:4].lower() != "http":
@@ -76,7 +77,7 @@ def _url_for_edit(request, obj):
 
 def _send_emailform_email(request, emailform, entry):
     subject = emailform.title
-    sender = local_settings.EMAILFORM_EMAIL_FROM
+    sender = emailform_settings.EMAILFORM_EMAIL_FROM
     recipients = list(set(x.strip() for x in emailform.email.split(',')))
     links = [(_url_for_edit(request, entry), "Edit Submission"),
              (_url_for_edit(request, emailform), "Edit Email Form"), ]
